﻿#  -*- coding: utf-8 -*-
#
#  NetzwerkMonitor E2
#
#  $Id$
#
#  Coded by Koepi (c) 2017
#  Support: board.dreambox-tools.info
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
from enigma import eTimer
from Components.ActionMap import ActionMap
from Components.ScrollLabel import ScrollLabel
from Components.Sources.StaticText import StaticText
from Plugins.Plugin import PluginDescriptor
from Screens.Screen import Screen
from Components.Button import Button
from Components.Network import iNetworkInfo
from Components.ConfigList import ConfigListScreen
from Components.config import config, ConfigSubsection, ConfigSelection, ConfigText, getConfigListEntry, ConfigOnOff, ConfigSet
config.plugins.NetzwerkMonitor = ConfigSubsection()
config.plugins.NetzwerkMonitor.bitbyte = ConfigOnOff(default = True)

Version = "V 3.0"

def main(session, **kwargs):
	session.open(NetzwerkMonitor)
	
def Plugins(**kwargs):
	return [PluginDescriptor(
		name="NetzwerkMonitor",
		description=_("Netzwerktraffic der Box"),
		where = [PluginDescriptor.WHERE_PLUGINMENU, PluginDescriptor.WHERE_EXTENSIONSMENU],
		icon="netzwerk.png",
		fnc = main)]	

class NetzwerkMonitor(Screen):
	skin = """
		<screen position="90,15" size="360,200" name="NetzwerkMonitor" title="NetzwerkMonitor">
			<eLabel text="Schnittstelle:" position="0,0" size="170, 34" font="Regular;28" foregroundColor="#00389416" zPosition="2" halign="right" />
			<widget name="port" position="180,0" size="220, 40" font="Regular;28" zPosition="2" foregroundColor="#00ffc435"/>
			<eLabel text="RX " position="0,60" size="100, 34" font="Regular;28" foregroundColor="#00389416" zPosition="2" halign="right" />
			<eLabel text="TX " position="0,100" size="100, 34" font="Regular;28" foregroundColor="#000064c7" zPosition="2" halign="right" />
			<widget name="rx_byte" position="100,60" size="270, 40" font="Regular;28" zPosition="2" halign="center" foregroundColor="#00389416"/>
			<widget name="tx_byte" position="100,100" size="270, 40" font="Regular;28" zPosition="2" halign="center" foregroundColor="#000064c7"/>
			<ePixmap pixmap="skin_default/buttons/red.png" position=  "0,160" size="140,40" alphatest="on" zPosition="2"/>
			<widget name="key_red" position=  "0,160" size="140,40" zPosition="3" font="Regular;20" halign="center" valign="center" foregroundColor="#00ffffff" transparent="1"	shadowColor="black" shadowOffset="-2,-2"/>
			<ePixmap pixmap="/usr/lib/enigma2/python/Plugins/Extensions/NetzwerkMonitor/key_ok.png" position="320,160" size="40,40" alphatest="on"/>
		</screen>"""

	def __init__(self, session):
		Screen.__init__(self, session)
		self.loop = eTimer()
		self.loop_conn = self.loop.timeout.connect(self.after)
		Screen.__init__(self, session, list)
		self["port"] = ScrollLabel("")
		self["rx_byte"] = ScrollLabel("")
		self["tx_byte"] = ScrollLabel("")
		self["key_ok"] = Button(_("ok"))
		self["key_red"] = Button(_("Cancel"))
		self["NetzwerkMonitorActionMap"] = ActionMap(["OkCancelActions", "ColorActions"],
		{
			"ok":	  self.ok,
			"red":	  self.cancel,			
			"cancel": self.cancel
		}, -1)
		self.setTitle(_("NetzwerkMonitor  ") + Version)
		bitbyte = ""
		self.bitbyte = bitbyte
		self.port = ""
		if (iNetworkInfo.isOnline()):
			self.onLayoutFinish.append(self.getInterfaces)
		iNetworkInfo.onStateChanged.append(self.network_onStateChanged)
	
	def network_onStateChanged(self, newstate):
		if (iNetworkInfo.isOnline()):
			self.getInterfaces()
		else:
			self.loop.stop() 
			self["port"].setText("Nicht Verbunden!")

	def getInterfaces(self):
		ifaces =  iNetworkInfo.getConfiguredInterfaces()
		for key, iface in ifaces.iteritems():
			self.port = key
			break
		if self.port:
			self.lan()

	def lan(self):
		if self.port:
			if self.port == "eth0":
				self["port"].setText("L a n")
			else:
				self["port"].setText(''.join("W L a n"))
			self.before()
		else:
			self["port"].setText("Nicht Verbunden!")
			
	def ok(self):
		self.session.open(NM_Setup)
			
	def cancel(self):
		self.loop.stop()
		iNetworkInfo.onStateChanged.remove(self.network_onStateChanged)
		self.close()
		
#--------------------------------------------------------------------------------------------------------
	def before(self):
		with open("/sys/class/net/%s/statistics/rx_bytes" % self.port, "r") as f:
			self.rx_byte_before = float(f.read())
		with open("/sys/class/net/%s/statistics/tx_bytes" % self.port, "r") as f:
			self.tx_byte_before = float(f.read())

		self.loop.start(1000)

	def after(self):
		bitbyte = self.bitbyte
		with open("/sys/class/net/%s/statistics/rx_bytes" % self.port, "r") as f:
			rx_byte_after = float(f.read())
		with open("/sys/class/net/%s/statistics/tx_bytes" % self.port, "r") as f:
			tx_byte_after = float(f.read())
		
		if not config.plugins.NetzwerkMonitor.bitbyte.value:
			wert = "Bit/s"
			rx_byte = (rx_byte_after - self.rx_byte_before) * 8 # Byte * 8 = Bit
			tx_byte = (tx_byte_after - self.tx_byte_before) * 8
		else:
			wert = "Byte/s"
			rx_byte = (rx_byte_after - self.rx_byte_before)
			tx_byte = (tx_byte_after - self.tx_byte_before)
		
		rx = float(rx_byte)
		r = "   "
		y = len(str(rx_byte))
		rx_byte = str(rx_byte)[:y-2]		
		if rx > 1024000:
			rx = rx / 1024000
			rx_byte = round(rx, 3)
			r = "M"
		elif rx > 1024:
			rx = rx / 1024
			rx_byte = round(rx, 3)
			r = "K"
		self["rx_byte"].setText("%s  " % rx_byte + r + wert)
	
		tx = float(tx_byte)
		r = "   "
		y = len(str(tx_byte))
		tx_byte = str(tx_byte)[:y-2]		
		if tx > 1024000:
			tx = tx / 1024000
			tx_byte = round(tx, 3)
			r = "M"
		elif tx > 1024:
			tx = tx / 1024
			tx_byte = round(tx, 3)
			r = "K"
		self["tx_byte"].setText("%s  " % tx_byte + r + wert)
	
		self.before()
#------------------------- Setup umschalten zwischen Bit/Byte -----------------------------------------------------------
class NM_Setup(Screen, ConfigListScreen):
	skin = """
		<screen name="NM_Setup" position="90,15" size="560,200" title="Main Settings">
			<widget name="config" position="5,5" size="550,360" scrollbarMode="showOnDemand" zPosition="1"/>
			<ePixmap pixmap="skin_default/buttons/red.png" position=  "0,160" size="140,40" alphatest="on" zPosition="2"/>
			<ePixmap pixmap="skin_default/buttons/green.png" position="400,160" size="140,40" alphatest="on" zPosition="2"/>
			<widget source="key_red" render="Label" position="20,170" zPosition="3" size="140,40" font="Regular;18" halign="left" valign="top" transparent="1" foregroundColor="white" backgroundColor="background"/>
			<widget source="key_green" render="Label" position="460,170" zPosition="3" size="140,40" font="Regular;18" halign="left" valign="top" transparent="1" foregroundColor="white" backgroundColor="background"/>
		</screen>"""
	def __init__(self, session):
		Screen.__init__(self, session)
		self.onChangedEntry = [ ]
		self.session = session
		
		self["actions"] = ActionMap(["SetupActions"],
			{
				"cancel": self.keyCancel,
				"save": self.keySave,
				"ok": self.keySave,
			}, -2)

		self["key_red"] = StaticText(_("Cancel"))
		self["key_green"] = StaticText(_("OK"))

		self.list = []
		ConfigListScreen.__init__(self, self.list, session = self.session, on_change = self.changedEntry)
		self.createSetup()
		self.onLayoutFinish.append(self.layoutFinished)

	def layoutFinished(self):
		self.setTitle(self.setup_title)

	def createSetup(self):
		self.list = []
		self.list.append(getConfigListEntry(_("Anzeige in Bit/s (off), Byte/s (on) :"), config.plugins.NetzwerkMonitor.bitbyte))
		self["config"].list = self.list
		self["config"].l.setList(self.list)

	def keyLeft(self):
		ConfigListScreen.keyLeft(self)

	def keyRight(self):
		ConfigListScreen.keyRight(self)
		
		
	def saveEntry(self):
		for x in self.onSaveEntry:
			x()
		self.close()
		
	def changedEntry(self):
		for x in self.onChangedEntry:
			x()

	def getCurrentEntry(self):
		return self["config"].getCurrent()[0]

	def getCurrentValue(self):
		return str(self["config"].getCurrent()[1].getText())

	def createSummary(self):
		from Screens.Setup import SetupSummary
		return SetupSummary
	
	def keyCancel(self):
		self.close()